/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import type { ContainerSchema, IFluidContainer, CompatibilityMode } from "@fluidframework/fluid-static";
import type { TinyliciousClientProps, TinyliciousContainerServices } from "./interfaces.js";
/**
 * Provides the ability to have a Fluid object backed by a Tinylicious service.
 *
 * @see {@link https://fluidframework.com/docs/testing/tinylicious/}
 *
 * @sealed
 * @public
 */
export declare class TinyliciousClient {
    private readonly documentServiceFactory;
    private readonly urlResolver;
    private readonly logger;
    /**
     * Creates a new client instance using configuration parameters.
     * @param properties - Optional. Properties for initializing a new TinyliciousClient instance
     */
    constructor(properties?: TinyliciousClientProps);
    /**
     * Creates a new detached container instance in Tinylicious server.
     * @param containerSchema - Container schema for the new container.
     * @param compatibilityMode - Compatibility mode the container should run in.
     * @returns New detached container instance along with associated services.
     */
    createContainer<TContainerSchema extends ContainerSchema>(containerSchema: TContainerSchema, compatibilityMode: CompatibilityMode): Promise<{
        container: IFluidContainer<TContainerSchema>;
        services: TinyliciousContainerServices;
    }>;
    /**
     * Accesses the existing container given its unique ID in the tinylicious server.
     * @param id - Unique ID of the container.
     * @param containerSchema - Container schema used to access data objects in the container.
     * @param compatibilityMode - Compatibility mode the container should run in.
     * @returns Existing container instance along with associated services.
     */
    getContainer<TContainerSchema extends ContainerSchema>(id: string, containerSchema: TContainerSchema, compatibilityMode: CompatibilityMode): Promise<{
        container: IFluidContainer<TContainerSchema>;
        services: TinyliciousContainerServices;
    }>;
    private getContainerServices;
    private getLoaderProps;
}
//# sourceMappingURL=TinyliciousClient.d.ts.map